function [ jacobian ] = calcJg( jointPos, d, a)
% Calculates the Jacobian of the system
%   Based on the joint position, and the d and a vector from the
%   DH-convention

K11 = sin(jointPos(2))*a(2);
K12 = sin(jointPos(2) + jointPos(3))*a(3); 
K13 = -cos(jointPos(2) + jointPos(3) + jointPos(4))*d(5) - sin(jointPos(2) + jointPos(3) + jointPos(4))*sin(jointPos(5))*d(6);
K21 = cos(jointPos(2))*a(2);
K22 = cos(jointPos(2) + jointPos(3))*a(3); 
K23 = sin(jointPos(2) + jointPos(3) + jointPos(4))*d(5) - cos(jointPos(2) + jointPos(3) + jointPos(4))*sin(jointPos(5))*d(6);

Css = sin(jointPos(1))*sin(jointPos(2) + jointPos(3) + jointPos(4));
Ccs = cos(jointPos(1))*sin(jointPos(2) + jointPos(3) + jointPos(4));
Csc = sin(jointPos(1))*cos(jointPos(2) + jointPos(3) + jointPos(4));
Ccc = cos(jointPos(1))*cos(jointPos(2) + jointPos(3) + jointPos(4));

C11 = K11 + K12 + K13; 
C12 = K12 + K13;
C13 = K13; 
C21 = K21 + K22 + K23; 
C22 = K22 + K23; 
C23 = K23; 

p06x = cos(jointPos(1))*cos(jointPos(2))*a(2) + cos(jointPos(1))*cos(jointPos(2) + jointPos(3))*a(3) + sin(jointPos(1))*d(4) + cos(jointPos(1))*sin(jointPos(2) + jointPos(3) + jointPos(4))*d(5) ...
+ (-cos(jointPos(1))*cos(jointPos(2) + jointPos(3) + jointPos(4))*sin(jointPos(5)) + sin(jointPos(1))*cos(jointPos(5)))*d(6);
p06y = sin(jointPos(1))*cos(jointPos(2))*a(2) + sin(jointPos(1))*cos(jointPos(2) + jointPos(3))*a(3) - cos(jointPos(1))*d(4) + sin(jointPos(1))*sin(jointPos(2) + jointPos(3) + jointPos(4))*d(5) ...
- (sin(jointPos(1))*cos(jointPos(2) + jointPos(3) + jointPos(4))*sin(jointPos(5)) + cos(jointPos(1))*cos(jointPos(5)))*d(6);

jacobian = [-p06y, -cos(jointPos(1))*C11, -cos(jointPos(1))*C12, -cos(jointPos(1))*C13, -sin(jointPos(1))*sin(jointPos(5))*d(6)-Css*cos(jointPos(5))*d(6), 0; ...
    p06x, -sin(jointPos(1))*C11, -sin(jointPos(1))*C12, -sin(jointPos(1))*C13, cos(jointPos(1))*sin(jointPos(5))*d(6)-Csc*cos(jointPos(5))*d(6), 0; ...
    0, C21, C22, C23, -sin(jointPos(2) + jointPos(3) + jointPos(4))*cos(jointPos(5))*d(6), 0; ...
    0, sin(jointPos(1)), sin(jointPos(1)), sin(jointPos(1)), Ccs, -Ccc*sin(jointPos(5))+sin(jointPos(1))*cos(jointPos(5)); ...
    0, -cos(jointPos(1)), -cos(jointPos(1)), -cos(jointPos(1)), Css, -Csc*sin(jointPos(5))-cos(jointPos(1))*cos(jointPos(5)); ...
    1, 0, 0, 0, -cos(jointPos(2) + jointPos(3) + jointPos(4)), -sin(jointPos(2) + jointPos(3) + jointPos(4))*sin(jointPos(5))];
% 
end

